@@ -132,7 +132,7 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
                     # =============================================================================
                     # # [PEAKSEARCH]
                     # =============================================================================
-                    "intensity_threshold" : 1,
+                    "intensity_threshold" : 2,
                     "boxsize" : 10,
                     "fit_peaks_gaussian" : 1,
                     "FitPixelDev" : 15,
@@ -159,9 +159,9 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
                     }
 
     generate_dataset = True
-    train_network = True
-    write_config_GUI = True
-    run_prediction = True
+    train_network = False
+    write_config_GUI = False
+    run_prediction = False
     prediction_GUI = False
     # =============================================================================
     # END OF USER INPUT
@@ -314,11 +314,20 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
         SG1 = input_params["SG"][1]
         
         ## read hkl information from a fit file in case too large HKLs
-        manual_hkl_list=False
+        manual_hkl_list=True
         if manual_hkl_list:
+            ##read from a text file (fit file)
             import numpy as np
-            temp = np.loadtxt(r"img_0000_LT_1.fit")
-            hkl_array = temp[:,2:5]
+            # temp = np.loadtxt(r"img_0000_LT_1.fit")
+            # hkl_array = temp[:,2:5]
+            # hkl_array1 = None
+            
+            ## or define your own list of hkls
+            import lauetoolsnn.lauetools.generaltools as GT
+            hkl_array = GT.threeindices_up_to(5)
+            hkl_max_index = np.max(np.abs(hkl_array), axis=1)
+            filter_cond = (hkl_max_index >= 3) * (hkl_max_index <= 4)
+            hkl_array = hkl_array[filter_cond]
             hkl_array1 = None
         else:
             hkl_array = None
@@ -378,8 +387,7 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
                          misorientation_angle = input_params["misorientation"], 
                          general_diff_rules = False, 
                          crystal = crystal, crystal1 = crystal1, 
-                         include_scm=input_params["include_small_misorientation"],
-                         mat_listHKl=hkl_array, mat_listHKl1=hkl_array1)
+                         include_scm=input_params["include_small_misorientation"])
         
         ############ GENERATING TESTING DATA ##############
         factor = 5 # validation split for the training dataset  --> corresponds to 20% of total training dataset
@@ -397,8 +405,7 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
                          misorientation_angle = input_params["misorientation"], 
                          general_diff_rules = False, 
                          crystal = crystal, crystal1 = crystal1, 
-                         include_scm=input_params["include_small_misorientation"],
-                         mat_listHKl=hkl_array, mat_listHKl1=hkl_array1)
+                         include_scm=input_params["include_small_misorientation"])
         
         ## Updating the ClassHKL list by removing the non-common HKL or less frequent HKL from the list
         ## The non-common HKL can occur as a result of the detector position and energy used
@@ -577,7 +584,8 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
             import multiprocessing, os, time, datetime
             import configparser, glob, re
             ## if LaueToolsNN is properly installed
-            from lauetoolsnn.utils_lauenn import  get_material_detail, new_MP_function, resource_path, global_plots
+            from lauetoolsnn.utils_lauenn import  get_material_detail, new_MP_function, resource_path, global_plots,\
+                write_average_orientation, convert_pickle_to_hdf5, write_prediction_stats, write_MTEXdata
             from lauetoolsnn.lauetools import dict_LaueTools as dictLT
             from lauetoolsnn.NNmodels import read_hdf5
             from keras.models import model_from_json
@@ -930,6 +938,36 @@ if __name__ == '__main__':     #enclosing required because of multiprocessing
                                   symmetry, symmetry1, crystal, crystal1], output_file)
             print("data saved in ", save_directory_)
             
+            ## Lets save also a set of average UB matrix in text file to be used with user_OM setting    
+            try:
+                write_average_orientation(save_directory_, mat_global, rotation_matrix,
+                                              match_rate, lim_x, lim_y, crystal, crystal1,
+                                              radius=10, grain_ang=5, pixel_grain_definition=3)
+            except:
+                print("Error with Average orientation and grain index calculation")
+                
+            try:
+                convert_pickle_to_hdf5(save_directory_, files_treated, rotation_matrix, strain_matrix, 
+                                       strain_matrixs, match_rate, spots_len, iR_pix, 
+                                       fR_pix, colx, coly, col, mat_global,
+                                       material_, material1_, lim_x, lim_y)
+            except:
+                print("Error writting H5 file")
+            
+            try:
+                write_prediction_stats(save_directory_, material_, material1_, files_treated,\
+                                        lim_x, lim_y, best_match, strain_matrixs, strain_matrix, iR_pix,\
+                                        fR_pix,  mat_global)
+            except:
+                print("Error writting prediction statistics file")
+                
+            try:
+                write_MTEXdata(save_directory_, material_, material1_, rotation_matrix,\
+                                   lattice_material, lattice_material1, lim_x, lim_y, mat_global,\
+                                    input_params["symmetry"][0], input_params["symmetry"][1])
+            except:
+                print("Error writting MTEX orientation file")
+                
             try:
                 global_plots(lim_x, lim_y, rotation_matrix, strain_matrix, strain_matrixs, 
                               col, colx, coly, match_rate, mat_global, spots_len, 
